@@ -10,9 +10,12 @@ with gzip.open(os.path.join(os.path.dirname(__file__), 'res', 'HAPT.pkl.gz'), 'r
 __remove_no_labels: pd.DataFrame = lambda remove_no_labels, df: df if not remove_no_labels else df[df.label != -1]
 
 def load_by_user(uid: int, remove_no_lavels=True) -> List[pd.DataFrame]:
-    if uid <= 30:
+    if uid > 30:
         return None
-    return __remove_no_labels(remove_no_lavels, __dfs[uid].copy())
+    result = list()
+    for df in __dfs[uid]:
+        result.append(__remove_no_labels(remove_no_lavels, df.copy()))
+    return result
 
 
 def load_all(remove_no_lavels=True) -> Dict[int, List[pd.DataFrame]]:
